@@ -35,6 +35,7 @@ import pydicom
 import gc
 import requests
 import csv
+import math
 #~ from multiprocessing import freeze_support
 #~ print "Imports finished!"
 
@@ -49,9 +50,10 @@ from .mdicom.mrenhanced import get_frame_ds
 from .mdicom.io import save_temp_ds
 from . import fileio
 from .threading import multithread
-import imp
+import importlib
 #~ print "Done!"
 from zipfile import ZipFile
+from .misc import cprint
 
 # WEB LINKS
 MIPPYDOCS = r'http://mippy.readthedocs.io'
@@ -113,13 +115,13 @@ class MIPPYMain(Frame):
 
 
 
-        '''
+        """
         This section is to determine the host OS, and set up the appropriate temp
         directory for images.
-        Windows = C:\Temp
+        Windows = C:\\Temp
         Mac = /tmp
         Linux = /tmp
-        '''
+        """
 
 
 
@@ -144,7 +146,11 @@ class MIPPYMain(Frame):
 
         # Use parallel processing?
         if not self.frozen:
-            self.multiprocess = True
+            if len(sys.argv)>1:
+                if sys.argv[1]=='multiprocess_off':
+                    self.multiprocess=False
+            else:
+                self.multiprocess = True
         else:
             self.multiprocess = False
 
@@ -404,6 +410,11 @@ class MIPPYMain(Frame):
         # Add progressbar
         self.master.progressbar = Progressbar(self.master, mode='determinate')
 
+        # Add progress number to use when loading a folder
+        self.master.statusmsg = StringVar()
+        self.master.statusmsg.set('')
+        self.master.statuslabel = Label(self.master,textvariable=self.master.statusmsg)
+
         # Use "grid" to position objects within "master"
         self.dirframe.grid(row=0,column=0,columnspan=2,rowspan=1,sticky='nsew')
         self.imcanvas.grid(row=1,column=0,sticky='nsew')
@@ -411,7 +422,8 @@ class MIPPYMain(Frame):
         self.loadmodulebutton.grid(row=2,column=1,sticky='nsew')
         #~ self.scrollbutton.grid(row=2,column=0,sticky='nsew')
         self.imcanvas.img_scrollbar.grid(row=2,column=0,sticky='ew')
-        self.master.progressbar.grid(row=3,column=0,rowspan=1,columnspan=2,sticky='nsew')
+        self.master.progressbar.grid(row=3,column=0,rowspan=1,columnspan=1,sticky='nsew')
+        self.master.statuslabel.grid(row=3,column=1,rowspan=1,columnspan=1,sticky='w')
 
         # Set row and column weights to handle resizing
         self.master.rowconfigure(0,weight=1)
@@ -491,9 +503,14 @@ class MIPPYMain(Frame):
                         self.active_series = parent
                     self.imcanvas.show_image(self.dirframe.dicomtree.index(item)+1)
 
-    def progress(self,percentage):
+    def progress(self,percentage,update=True):
         self.master.progressbar['value']=percentage
-        self.master.progressbar.update()
+        if update:
+            self.master.progressbar.update()
+    
+    def status(self,message):
+        self.master.statusmsg.set(message)
+        self.master.statuslabel.update()
 
     def load_preview_images(self, uid_array):
         """
@@ -565,7 +582,7 @@ class MIPPYMain(Frame):
         if self.multiprocess and not (('win' in sys.platform and not 'darwin' in sys.platform)
                                 and len(self.path_list)<20):
             f = partial(collect_dicomdir_info,tempdir=self.tempdir)
-            self.tag_list = multithread(f,self.path_list,progressbar=self.progress)
+            self.tag_list = multithread(f,self.path_list,progressbar=self.progress,status=self.status)
 
             self.tag_list = [item for sublist in self.tag_list for item in sublist]
             self.tag_list = [value for value in self.tag_list if value != []]
@@ -583,8 +600,10 @@ class MIPPYMain(Frame):
                         else:
                             errors.append(row)
             self.progress(0.)
+            self.status('')
         # This should sort the list into your initial order for the tree - maybe implement a more customised sort if necessary?
         from operator import itemgetter
+        self.status("Sorting DICOM files")
         self.sorted_list = sorted(self.tag_list, key=itemgetter('name','date','time','studyuid','series','seriesuid','instance','instanceuid'))
 
         if len(errors)>0:
@@ -622,7 +641,16 @@ class MIPPYMain(Frame):
         n_repeats = 0
         uid_list = []
         to_remove = []
+        self.status("Building DICOM tree")
+        progress_update = 0
+        i = 0
+        # for i in range(len(self.sorted_list)):
         for scan in self.sorted_list:
+            i+=1
+            current_progress=math.floor(float(i)/float(len(self.sorted_list))*100.)
+            if current_progress>progress_update:
+                progress_update=current_progress
+                self.progress(float(progress_update))
             #~ print "Adding to tree: "+scan['path']
             if not self.dirframe.dicomtree.exists(scan['studyuid']):
                 #~ i+=1
@@ -646,9 +674,11 @@ class MIPPYMain(Frame):
             # EXPERIMENTAL - Remove repeated instance from list
             # print("REMOVED: {}".format(scan['seriesdesc']))
             self.sorted_list.remove(scan)
+        self.progress(0.)
 
         if repeats_found:
             tkinter.messagebox.showwarning("WARNING",str(n_repeats)+" repeat image UID's found and ignored.")
+        self.status(f"{len(self.sorted_list)} DICOM instances loaded")
         self.dirframe.dicomtree.update()
         # print("UIDS: {}".format(len(uid_list)))
         # print("IMS: {}".format(len(self.sorted_list)))
@@ -663,7 +693,7 @@ class MIPPYMain(Frame):
         return
 
     def select_modules_directory(self):
-        print("Load module directory")
+        # print("Load module directory")
 
 
         # for line in sys.path:
@@ -820,7 +850,7 @@ class MIPPYMain(Frame):
                                             print("Local version is newer! Weird...")
 
                                 except requests.exceptions.ConnectionError:
-                                    print("Unable to connect to repository for version check")
+                                    cprint("ERROR: Unable to connect to repository for version check")
 
 
 
@@ -858,7 +888,7 @@ class MIPPYMain(Frame):
                                                 for mod in self.module_list:
                                                     if (module_info['dirname']==mod['dirname'] and
                                                         module_info['version']==mod['version']):
-                                                        print("MODULE CLASH: {} {}".format(module_info['dirname'],module_info['version']))
+                                                        cprint("ERROR: MODULE CLASH: {} {}".format(module_info['dirname'],module_info['version']))
                                                         self.module_info = []
                                                         return
 
@@ -899,7 +929,7 @@ class MIPPYMain(Frame):
                         for mod in self.module_list:
                             if (module_info['dirname']==mod['dirname'] and
                                 module_info['version']==mod['version']):
-                                print("MODULE CLASH: {} {}".format(module_info['dirname'],module_info['version']))
+                                cprint("ERROR: MODULE CLASH: {} {}".format(module_info['dirname'],module_info['version']))
                                 self.module_list = []
                                 return
 
@@ -983,7 +1013,7 @@ class MIPPYMain(Frame):
         """
         This has been removed for the time being.
         """
-        print("Display changelog")
+        # print("Display changelog")
         info = ""
         with open('docs/changelog.info','rb') as infofile:
             info = infofile.read()
@@ -1016,7 +1046,7 @@ class MIPPYMain(Frame):
             moduledir = selected_module.split('^')[0]
             name = self.moduleframe.moduletree.item(selected_module)['text']
             version = self.moduleframe.moduletree.item(selected_module)['values'][2]
-            print(name,version)
+            # print(name,version)
             module_name = moduledir+'.module_main'
             for mod in self.module_list:
                 if moduledir==mod['dirname'] and version==mod['version']:
@@ -1058,12 +1088,12 @@ class MIPPYMain(Frame):
             #     print(path)
             # print("Loader:\n{}".format(importlib.find_loader(module_name)))
             active_module = importlib.import_module(module_name)
-            imp.reload(active_module)
+            importlib.reload(active_module)
 #            if not module_name in sys.modules:
 #                active_module = importlib.import_module(module_name)
 #            else:
 #                active_module = importlib.import_module(module_name)
-#                imp.reload(active_module)
+#                importlib.reload(active_module)
             preload_dicom = active_module.preload_dicom()
             try:
                 flatten_list = active_module.flatten_series()
@@ -1078,7 +1108,7 @@ class MIPPYMain(Frame):
                         "or return True if you require all\n"+
                         "images in a single 1D list.\n"+
                         "======================================\n\n")
-                print(message)
+                cprint(message)
                 flatten_list = True
             if preload_dicom:
                 # Attempted to make this section discrete function for use in modules etc
@@ -1152,8 +1182,7 @@ class MIPPYMain(Frame):
             active_module.execute(self.master,instance_info,self.datasets_to_pass)
         except:
             raise
-            print("Did you select a module?")
-            print("Bet you didn't.")
+            cprint("ERROR: No module selected")
         return
 
 
@@ -1179,7 +1208,12 @@ class MIPPYMain(Frame):
                 ds = pydicom.dcmread(tag['path'])
                 if 'SpectroscopyData' in dir(ds):
                     ds.SpectroscopyData=0
+                dcm_view.text.insert(END,str(ds.file_meta)+'\n')
                 dcm_view.text.insert(END,str(ds))
+                # Try and get Siemens CSA header
+                if 'SIEMENS' in ds.Manufacturer.upper():
+                    from .mdicom.siemens import get_ascconv
+                    dcm_view.text.insert(END,'\n'.join([':\t'.join(a) for a in get_ascconv(ds)]))
                 dcm_view.text.config(state='disabled')
                 dcm_view.text.see('1.0')
                 dcm_view.text.pack()
@@ -1242,14 +1276,14 @@ class MIPPYMain(Frame):
         self.exportdir = None
         return
 
-    def show_log(self):
-        logwin = Toplevel()
-        logtext = ScrolledText.ScrolledText(logwin)
-        with open(self.logpath,'rb') as logfile:
-            text = logfile.readlines()
-            for row in text:
-                logtext.insert(END,row+'\n')
-        logtext.pack()
+    # def show_log(self):
+    #     logwin = Toplevel()
+    #     logtext = ScrolledText.ScrolledText(logwin)
+    #     with open(self.logpath,'rb') as logfile:
+    #         text = logfile.readlines()
+    #         for row in text:
+    #             logtext.insert(END,row+'\n')
+    #     logtext.pack()
 
     def enable_multiprocessing(self):
         if self.frozen:
