@@ -7,6 +7,11 @@ import fnmatch
 import stat
 import itertools
 
+import pydicom
+from pydicom.dataset import FileDataset, Dataset
+import pydicom.uid
+from pydicom.uid import generate_uid, PYDICOM_IMPLEMENTATION_UID, ImplicitVRLittleEndian, UID
+
 def list_all_files(dirpath,recursive=False):
         pathlist = []
         if recursive:
@@ -58,6 +63,19 @@ def export_dicom_file(ds,outdir):
         dir2 = ds.StudyDate+"_"+ds.StudyTime
         dir3 = str(ds.SeriesNumber).zfill(4)+"_"+remove_invalid_characters(str(ds.SeriesDescription))
 
+        if 'ENHANCED' in ds.file_meta.MediaStorageSOPClassUID.name.upper():
+              ds.file_meta.MediaStorageSOPClassUID = UID('1.2.840.10008.5.1.4.1.1.4')        # Set to MR Image Storage if saving datasets split from enhanced DICOM
+        
+        
+        # ds.file_meta.MediaStorageSOPClassUID = ref[i].file_meta.MediaStorageSOPClassUID
+        ds.file_meta.ImplementationClassUID = PYDICOM_IMPLEMENTATION_UID
+        ds.file_meta.MediaStorageSOPInstanceUID = generate_uid()
+        # ds.file_meta.TransferSyntaxUID = ImplicitVRLittleEndian
+
+        ds.SeriesInstanceUID = ds.SeriesInstanceUID+'.1'
+        ds.SOPInstanceUID = generate_uid()
+        # ds.StudyInstanceUID = ref[i].StudyInstanceUID
+
         #~ fname1 = str(ds.ImageType).replace('/','-').strip()+"_"
         fname1 = ''.join(str(i)+"_" for i in ds.ImageType)
         fname2 = str(ds.SeriesNumber).zfill(4)+"_"
