@@ -57,20 +57,13 @@ def find_object_geometry(image,subpixel=True,search_region=None,threshold=None,i
         print("Starting values: {},{},{},{}".format(xc,yc,xr,yr))
         print("Fitting ellipse")
         best_ellipse = minimize(object_fit_ellipse,(xc,yc,xr,yr),args=(px_binary),method='Nelder-Mead',options={'maxiter':30})
-        #~ best_ellipse = minimize(object_fit_ellipse,(xc,yc,xr,yr),args=(px_binary),options={'maxiter':10})
-        #~ print best_ellipse.success
         print("Fitting rectangle")
         best_rectangle = minimize(object_fit_rectangle,(xc,yc,xr,yr),args=(px_binary),method='Nelder-Mead',options={'maxiter':30})
-        #~ best_rectangle = minimize(object_fit_rectangle,(xc,yc,xr,yr),args=(px_binary),options={'maxiter':10})
-        #~ print best_rectangle.success
 
         ellipse_val = best_ellipse.fun
         rectangle_val = best_rectangle.fun
 
-        #~ print ellipse_val
-        #~ print rectangle_val
-
-        if ellipse_val < rectangle_val:
+        if ellipse_val <= rectangle_val:
                 result = best_ellipse.x
                 shapetype='ellipse'
         elif ellipse_val > rectangle_val:
