@@ -1,4 +1,5 @@
 IMPLEMENTATIONS_AVAILABLE = [
     'syngo_mr_xa20a',
-    'syngo_mr_xa31a'
+    'syngo_mr_xa31a',
+    'SIEMENS'
 ]
