@@ -34,6 +34,10 @@ def get_px_array(ds,enhanced=False,instance=None,bitdepth=None):
                         # Problem with some DICOM encoders (namely PukkaJ) that don't write the 2005,140f tag
                         # properly.  This is currently unrecoverable, so just assume ss doesn't exist.
                         ss = None
+                except ValueError:
+                        # Another problem with file encoding, potentially to do with export via Siemens SyngoVia??
+                        # Tag exists, can read it, but can't make a number out of it.
+                        ss = None
                 except:
                         raise
         except:
@@ -243,7 +247,7 @@ def generate_4d_array(dicom_paths):
         series_number = ds.SeriesNumber
         try:
             series_description = ds.SeriesDescription
-        except AttibuteError:
+        except AttributeError:
             series_description = "UNKNOWN SERIES DESCRIPTION"
 
         if i==1:
