@@ -17,6 +17,11 @@ from ..threading import multithread
 from functools import partial
 from .mrenhanced import get_frame_ds
 import itertools
+from ..misc import cprint
+
+from multiprocessing import Lock
+
+print_lock = Lock()
 
 def recursive_file_finder(path):
         pathlist = []
@@ -67,14 +72,14 @@ def get_dataset(info,tempdir=None):
         if not uid is None:
                 temppath = os.path.join(tempdir,str(uid)+'.mds')
                 if os.path.exists(temppath):
-                        print("TEMP FILE FOUND: "+str(uid))
+                        # print("TEMP FILE FOUND: "+str(uid))
                         with open(temppath,'rb') as tempfile:
                                 ds = pickle.load(tempfile)
                         return ds
                 elif not filepath is None:
                         ds = pydicom.dcmread(filepath)
                         if not 'ENHANCED' in ds.SOPClassUID.name.upper():
-                                print("SINGLE DICOM FILE FOUND")
+                                # print("SINGLE DICOM FILE FOUND")
                                 io.save_temp_ds(ds,tempdir,str(ds.SOPInstanceUID)+'.mds')
                                 return ds
                         else:
@@ -86,7 +91,7 @@ def get_dataset(info,tempdir=None):
                                         return ds_split
 
         # If it's got this far, cannot find file or not enough info
-        print("CANNOT FIND FILE")
+        cprint(f"ERROR: Cannot find image file - {uid}\n\tPlease reload the image directory.")
         return None
 
 
@@ -112,8 +117,9 @@ def collect_dicomdir_info(path,tempdir=None,force_read=False):
                 # Removed this garbage collection call to try speed up directory reading
                 #~ gc.collect()
         except Exception:
-                print(path+'\n...is not a valid DICOM file and is being ignored.')
+                # cprint(f"INFO: {path}\n\t...is not a valid DICOM file and is being ignored.")
                 return tags
+                raise #temp debugging
         if ds and not ds is None:
                 #~ print path
 
@@ -199,8 +205,7 @@ def collect_dicomdir_info(path,tempdir=None,force_read=False):
                         try:
                                 instance = [ds.InstanceNumber]
                         except AttributeError:
-                                print("INSTANCE NUMBER TAG DOESN'T EXIST")
-                                print(path)
+                                cprint(f"ERROR: InstanceNumber tag doesn't exist\n\t{path}")
                                 raise
 
                 instance_uid = 'UNKNOWN'
@@ -256,10 +261,11 @@ def collect_dicomdir_info(path,tempdir=None,force_read=False):
                                 # Check if temp file already exists for that InstanceUID. If so, read that file. If not,
                                 # uncompress the file and replace ds. Dataset will get saved as temp file at the end of this
                                 # function.
+                                cprint(f"WARNING: Compressed DICOM - {path}")
                                 temppath = os.path.join(tempdir,instance_uid+'.mds')
                                 if os.path.exists(temppath):
-                                        print(seriesdesc+' '+str(i).zfill(3))
-                                        print("    COMPRESSED DICOM - Temp file found")
+                                        # print(seriesdesc+' '+str(i).zfill(3))
+                                        # print("    COMPRESSED DICOM - Temp file found")
                                         with open(temppath,'rb') as tempfile:
                                                 ds = pickle.load(tempfile)
                                         tempfile.close()
@@ -272,12 +278,11 @@ def collect_dicomdir_info(path,tempdir=None,force_read=False):
                                                 elif 'win' in sys.platform:
                                                         dcmdjpeg = os.path.join(tempdir,"dcmdjpeg_win.exe")
                                                 else:
-                                                        print("UNSUPPORTED OPERATING SYSTEM")
-                                                        print(str(sys.platform))
+                                                        cprint(f"ERROR: UNSUPPORTED OPERATING SYSTEM - {sys.platform}")
                                         # Uncompress the file
                                         outpath=os.path.join(tempdir,'UNCOMP_'+instance_uid+'.DCM')
-                                        print(seriesdesc+' '+str(i).zfill(3))
-                                        print("    COMPRESSED DICOM - Uncompressing")
+                                        # print(seriesdesc+' '+str(i).zfill(3))
+                                        # print("    COMPRESSED DICOM - Uncompressing")
                                         command = [dcmdjpeg,'-v',path,outpath]
                                         call(command, shell=False)
                                         del(ds)
@@ -288,12 +293,12 @@ def collect_dicomdir_info(path,tempdir=None,force_read=False):
                                                 ds.is_little_endian = True
                                                 ds.is_implicit_VR = False
 
-                        print(name,"/",date,"/",seriesdesc,"/",i)
+                        # cprint(name,"/",date,"/",seriesdesc,"/",i)
 #                        print(mode.upper())
                         if not ("SPECTROSCOPY" in mode.upper() or ima_mrs_uid in mode.upper()):
                                 pxfloat=pixel.get_px_array(ds,enhanced,i,bitdepth=8)
                                 if pxfloat is None:
-                                        print("ERROR: Couldn't read pixel data")
+                                        # print("ERROR: Couldn't read pixel data")
                                         continue
                                 try:
                                         overlay = get_overlay(ds)
@@ -328,6 +333,7 @@ def collect_dicomdir_info(path,tempdir=None,force_read=False):
         return tags
     except Exception as e:
         return [{'state':'ERROR','path':path,'exception':e}]
+        # raise
 
 def compare_dicom(ds1,ds2,diffs=None,num=None,name=''):
         if diffs is None:
